@@ -89,7 +89,7 @@
 #'  \item For quick, accurate, and searchable plotly.js reference: [schema()]
 #' }
 #' @export
-#' @examples
+#' @examplesIf interactive() || !identical(.Platform$OS.type, "windows")
 #' \dontrun{
 #' 
 #' # plot_ly() tries to create a sensible plot based on the information you 
@@ -263,7 +263,7 @@ plot_mapbox <- function(data = data.frame(), ...) {
 #' @export
 #' @author Carson Sievert
 #' @seealso [plot_ly()], [plot_mapbox()], [ggplotly()] 
-#' @examples
+#' @examplesIf interactive() || !identical(.Platform$OS.type, "windows")
 #' 
 #' map_data("world", "canada") %>%
 #'   group_by(group) %>%
@@ -274,7 +274,7 @@ plot_geo <- function(data = data.frame(), ..., offline = FALSE) {
   p <- plot_ly(data, ...)
   
   if (isTRUE(offline)) {
-    if (system.file(package = "plotlyGeoAssets") == "") {
+    if (!is_installed("plotlyGeoAssets")) {
       stop(
         "The plotlyGeoAssets package is required to make 'offline' maps. ",
         "Please install and try again.",
@@ -308,7 +308,7 @@ plot_geo <- function(data = data.frame(), ..., offline = FALSE) {
 #' @export
 #' @author Carson Sievert
 #' @seealso [plot_ly()], [plot_mapbox()], [ggplotly()] 
-#' @examples
+#' @examplesIf interactive() || !identical(.Platform$OS.type, "windows")
 #' 
 #' \dontrun{
 #' hc <- hclust(dist(USArrests), "ave")
@@ -400,7 +400,7 @@ get_xy <- function(node) {
 #' @param x a plotly object.
 #' @param ... other options passed onto `htmlwidgets::createWidget`
 #' @export
-#' @examples 
+#' @examplesIf interactive() || !identical(.Platform$OS.type, "windows")
 #' 
 #' trace <- list(x = 1, y = 1)
 #' obj <- list(data = list(trace), layout = list(title = "my plot"))
@@ -479,7 +479,7 @@ typedArrayPolyfill <- function() {
 plotlyMainBundle <- function() {
   htmltools::htmlDependency(
     name = "plotly-main", 
-    version = "2.5.1",
+    version = "2.11.1",
     package = "plotly",
     src = dependency_dir("plotlyjs"),
     script = "plotly-latest.min.js",
@@ -491,7 +491,7 @@ plotlyMainBundlePath <- function() {
   dep <- plotlyMainBundle()
   path <- file.path(dep$src$file, dep$script)
   if (!is.null(dep$package)) {
-    path <- system.file(path, package = dep$package)
+    path <- system_file(path, package = dep$package)
   }
   path
 }
@@ -513,7 +513,7 @@ locale_dependency <- function(locale) {
   }
   
   locale_dir <- dependency_dir("plotlyjs", "locales")
-  locales_all <- sub("\\.js$", "", list.files(system.file(locale_dir, package = "plotly")))
+  locales_all <- sub("\\.js$", "", list.files(system_file(locale_dir, package = "plotly")))
   if (!tolower(locale) %in% locales_all) {
     stop(
       "Invalid locale: '", locale, "'.\n\n",
@@ -553,7 +553,7 @@ locale_dependency <- function(locale) {
 #'
 #' @param p a plotly object
 #' @export
-#' @examples 
+#' @examplesIf interactive() || !identical(.Platform$OS.type, "windows")
 #' 
 #' \dontrun{
 #' p1 <- plot_ly()
