@@ -1,4 +1,3 @@
-context("plotly-symbol")
 
 expect_traces <- function(p, n.traces, name){
   stopifnot(is.numeric(n.traces))
@@ -8,7 +7,10 @@ expect_traces <- function(p, n.traces, name){
 }
 
 test_that("Mapping a variable to symbol works", {
-  p <- plot_ly(iris, x = ~Sepal.Length, y = ~Petal.Length, symbol = ~Species)
+  d <- palmerpenguins::penguins %>% 
+    filter(!is.na(bill_length_mm))
+  p <- plot_ly(d, x = ~bill_length_mm, 
+               y = ~bill_depth_mm, symbol = ~species)
   l <- expect_traces(p, 3, "scatterplot-symbol")
   markers <- lapply(l$data, "[[", "marker")
   syms <- unlist(lapply(markers, "[[", "symbol"))
@@ -16,8 +18,10 @@ test_that("Mapping a variable to symbol works", {
 })
 
 test_that("Can set the symbol range.", {
-  p <- plot_ly(iris, x = ~Sepal.Length, y = ~Petal.Length, symbol = ~Species, 
-               symbols = 1:3)
+  d <- palmerpenguins::penguins %>% 
+    filter(!is.na(bill_length_mm))
+  p <- plot_ly(d, x = ~bill_length_mm, 
+               y = ~bill_depth_mm, symbol = ~species, symbols = 1:3)
   l <- expect_traces(p, 3, "scatterplot-symbol2")
   markers <- lapply(l$data, "[[", "marker")
   syms <- unlist(lapply(markers, "[[", "symbol"))
@@ -26,15 +30,16 @@ test_that("Can set the symbol range.", {
 
 
 test_that("Setting a constant symbol works", {
-  p <- plot_ly(iris, x = 1:25, y = 1:25, symbol = I(0:24))
+  #keep only 6 observations (to avoid warning of max 6 symbol)
+  p <- plot_ly(palmerpenguins::penguins[1:6], x = 1:6, y = 1:6, symbol = I(0:5))
   l <- expect_traces(p, 1, "pch")
   markers <- lapply(l$data, "[[", "marker")
   syms <- unlist(lapply(markers, "[[", "symbol"))
-  expect_identical(syms, plotly:::pch2symbol(0:24))
+  expect_identical(syms, plotly:::pch2symbol(0:5))
 })
 
 test_that("Warn about invalid symbol codes", {
-  p <- plot_ly(iris, x = ~Sepal.Length, y = ~Petal.Length, symbol = I("DNE"))
+  p <- plot_ly(palmerpenguins::penguins, x = ~bill_length_mm, y = ~bill_depth_mm, symbol = I("DNE"))
   expect_warning(plotly_build(p), "DNE")
 })
 
@@ -63,8 +68,11 @@ test_that("Trace ordering matches factor levels", {
 })
 
 test_that("Trace ordering is alphabetical", {
-  lvls <- sort(unique(mpg$class))
-  p <- plot_ly(mpg, x = ~cty, y = ~hwy, symbol = ~class)
+  #keep only 6 categories (to avoid warning)
+  mpg2 <- mpg %>% dplyr::filter(class %in% c("compact", "midsize", "suv", "2seater", "pickup", "subcompact"))
+  
+  lvls <- sort(unique(mpg2$class))
+  p <- plot_ly(mpg2, x = ~cty, y = ~hwy, symbol = ~class)
   l <- expect_traces(p, length(lvls), "alphabetical")
   expect_equivalent(sapply(l$data, "[[", "name"), lvls)
 })
